==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/feedback_links.dart <==
part of keyclic_sdk_api.api;

class FeedbackLinks {
  FeedbackLinks({
    this.self,
    this.category,
    this.businessActivity,
    this.reporter,
    this.image,
    this.tracking,
    this.images,
  });

  FeedbackLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    self = FeedbackLinksSelf.fromJson(json['self']);
    category = FeedbackLinksCategory.fromJson(json['category']);
    businessActivity =
        FeedbackLinksBusinessActivity.fromJson(json['businessActivity']);
    reporter = FeedbackLinksReporter.fromJson(json['reporter']);
    image = FeedbackLinksImage.fromJson(json['image']);
    tracking = FeedbackLinksTracking.fromJson(json['tracking']);
    images = FeedbackLinksImages.listFromJson(json['images']);
  }

  FeedbackLinksSelf self;

  FeedbackLinksCategory category;

  FeedbackLinksBusinessActivity businessActivity;

  FeedbackLinksReporter reporter;

  FeedbackLinksImage image;

  FeedbackLinksTracking tracking;

  List<FeedbackLinksImages> images;

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is FeedbackLinks && runtimeType == other.runtimeType;
  }

  @override
  int get hashCode => 0;

  Map<String, dynamic> toJson() {
    return {
      'self': self,
      'category': category,
      'businessActivity': businessActivity,
      'reporter': reporter,
      'image': image,
      'tracking': tracking,
      'images': images,
    };
  }

  @override
  String toString() {
    return 'FeedbackLinks[self=$self, category=$category, businessActivity=$businessActivity, reporter=$reporter, image=$image, tracking=$tracking, images=$images, ]';
  }

  static List<FeedbackLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? List<FeedbackLinks>()
        : json.map((value) => FeedbackLinks.fromJson(value)).toList();
  }

  static Map<String, FeedbackLinks> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, FeedbackLinks>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = FeedbackLinks.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/feedback_links.dart <==
part of keyclic_sdk_api.api;

class FeedbackLinks {
  FeedbackLinks({
    this.businessActivity,
    this.category,
    this.image,
    this.images,
    this.reporter,
    this.self,
    this.tracking,
  });

  FeedbackLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    businessActivity =
        FeedbackLinksBusinessActivity.fromJson(json['businessActivity']);
    category = FeedbackLinksCategory.fromJson(json['category']);
    image = FeedbackLinksImage.fromJson(json['image']);
    images = FeedbackLinksImages.listFromJson(json['images']);
    reporter = FeedbackLinksReporter.fromJson(json['reporter']);
    self = FeedbackLinksSelf.fromJson(json['self']);
    tracking = FeedbackLinksTracking.fromJson(json['tracking']);
  }

  FeedbackLinksBusinessActivity businessActivity;

  FeedbackLinksCategory category;

  FeedbackLinksImage image;

  List<FeedbackLinksImages> images;

  FeedbackLinksReporter reporter;

  FeedbackLinksSelf self;

  FeedbackLinksTracking tracking;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is FeedbackLinks &&
        runtimeType == other.runtimeType &&
        businessActivity == other.businessActivity &&
        category == other.category &&
        image == other.image &&
        DeepCollectionEquality.unordered().equals(images, other.images) &&
        reporter == other.reporter &&
        self == other.self &&
        tracking == other.tracking;
  }

  /// By default hashCode return reference
  @override
  int get hashCode =>
      0 ^
      businessActivity.hashCode ^
      category.hashCode ^
      image.hashCode ^
      images.map((dynamic element) => element.hashCode).fold(0,
          (dynamic value, dynamic cursor) => value.hashCode ^ cursor.hashCode) ^
      reporter.hashCode ^
      self.hashCode ^
      tracking.hashCode;

  static List<FeedbackLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? <FeedbackLinks>[]
        : json.map((value) => FeedbackLinks.fromJson(value)).toList();
  }

  static Map<String, FeedbackLinks> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, FeedbackLinks>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = FeedbackLinks.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'businessActivity': businessActivity,
      'category': category,
      'image': image,
      'images': images,
      'reporter': reporter,
      'self': self,
      'tracking': tracking,
    };
  }

  @override
  String toString() {
    return 'FeedbackLinks[businessActivity=$businessActivity, category=$category, image=$image, images=$images, reporter=$reporter, self=$self, tracking=$tracking, ]';
  }
}
